@@ -32,4 +32,7 @@ PUPPETDB_FACT_LIST = [
 ]
 
 # Name of common role item in database
-COMMON_ROLE = 'COMMON'
\ No newline at end of file
+COMMON_ROLE = 'COMMON'
+
+# Path to local configuration file
+CONFIG_FILE = '/etc/puppetencconfig.yml'
\ No newline at end of file
